pbs.h
changeset 2164 74c8163d1e14
parent 2159 3b634157c3b2
child 2186 461a2aff3486
--- a/pbs.h	Fri Jul 22 07:02:20 2005 +0000
+++ b/pbs.h	Fri Jul 22 08:40:19 2005 +0000
@@ -72,12 +72,13 @@
  * @return True when there are pbs signals on that tile
  */
 
-bool PBSIsPbsDepot(uint tile);
+bool PBSIsPbsSegment(uint tile, Trackdir trackdir);
 /**<
  * Checks if a depot is inside a pbs block.
  * Tis means that the block it is in needs to have at least 1 signal, and that all signals in it need to be pbs signals.
  * @param tile The depot tile to check
  * @return True when the depot is inside a pbs block.
  */
 
 #endif
@@ -72,12 +72,13 @@
 /**<
- * Checks if a depot is inside a pbs block.
- * Tis means that the block it is in needs to have at least 1 signal, and that all signals in it need to be pbs signals.
- * @param tile The depot tile to check
- * @return True when the depot is inside a pbs block.
+ * Checks if a signal/depot leads to a pbs block.
+ * This means that the block needs to have at least 1 signal, and that all signals in it need to be pbs signals.
+ * @param tile The tile to check
+ * @param trackdir The direction in which to check
+ * @return True when the depot is inside a pbs block
  */
 